"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.updateVersion = void 0;
const fs_1 = require("fs");
const path_1 = require("path");
const promisified_properties_1 = require("promisified-properties");
const gradle_1 = require("./gradle");
async function updateVersion(cwd, version) {
    const path = (0, path_1.join)(cwd, "gradle.properties");
    let prop = new Map();
    if ((0, fs_1.existsSync)(path)) {
        prop = await (0, promisified_properties_1.parseFile)(path);
    }
    prop.set("version", version);
    return (0, promisified_properties_1.write)(prop, path);
}
exports.updateVersion = updateVersion;
async function prepare(pluginConfig, context) {
    const { cwd, env, nextRelease } = context;
    await updateVersion(cwd, nextRelease.version);
    const version = await (0, gradle_1.getVersion)(cwd, env);
    if (version !== nextRelease.version) {
        throw new Error(`Failed to update version from ${version} to ${nextRelease.version}. ` +
            "Make sure that you define version not in build.gradle but in gradle.properties.");
    }
}
exports.default = prepare;
